@@ -7,7 +7,7 @@ use Env qw( @PATH );
 use File::Spec;
 
 # ABSTRACT: Find or build GNU Make
-our $VERSION = '0.10'; # VERSION
+our $VERSION = '0.11'; # VERSION
 
 
 my $in_path;
@@ -35,8 +35,7 @@ sub alien_helper
       # return the executable name for GNU make,
       # usually either make or gmake depending on
       # the platform and environment
-      my($class) = @_;
-      $class->exe;
+      Alien::gmake->exe;
     },
   }
 }
@@ -55,7 +54,7 @@ Alien::gmake - Find or build GNU Make
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =head1 SYNOPSIS
 
